View source: R/partial_invariance.R
| identify_items_partial | R Documentation |
This function uses 2 lavaan functions to generate a table (in tibble format) to identify which items and specifications among the groups could be generating problematic situations.
identify_items_partial(fit, cutoff.value = 0.1, detailed = FALSE)
fit |
A lavaan object that is estimated by |
cutoff.value |
By default, only p-values below 0.10 are retained.
If you want to obtain all of them in their entirety, indicate the value
as |
detailed |
Defaults to FALSE, and will display only the essential
information requested. If you want the complete columns obtained with
|
A tibble::tibble() to identify items and specifications that,
when indicated, could solve non-invariance problems.
lavaan::parTable(), lavaan::lavTestScore()
library(semTools)
HS.model <- ' visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9 '
fit_scalar <- measEq.syntax(configural.model = HS.model,
data = lavaan::HolzingerSwineford1939,
estimator = "MLR",
parameterization = "theta",
ID.fac = "std.lv",
ID.cat = "Wu.Estabrook.2016",
group = "sex",
group.equal = c("loadings", "intercepts"),
return.fit = TRUE)
identify_items_partial(fit_scalar)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.